@@ -1,5 +1,7 @@
 """
-Logger
+log.py
+
+Author: Joseph Maclean Arhin
 """
 
 import logging
@@ -11,6 +13,7 @@ class RequestFormatter(logging.Formatter):
     """
     Request formatter to handle log format
     """
+
     def format(self, record):
         if has_request_context():
             record.url = request.url
